========
Siteship
========


.. image:: https://img.shields.io/pypi/v/siteship.svg
        :target: https://pypi.python.org/pypi/siteship

.. image:: https://img.shields.io/travis/siteship/siteship-cli.svg
        :target: https://travis-ci.org/siteship/siteship-cli

.. image:: https://readthedocs.org/projects/siteship-cli/badge/?version=latest
        :target: https://siteship-cli.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/siteship/siteship-cli/shield.svg
     :target: https://pyup.io/repos/github/siteship/siteship-cli/
     :alt: Updates


Static websites deployments made simple


* Free software: MIT license
* Documentation: https://siteship.readthedocs.io.


Features
--------
